@@ -1,3 +1,6 @@
+from . import utils
+from .utils import critical_section
+
 from .template_component import template_component
 from .audio_input import audio_input
 from .version import VERSION as __version__
